# Apex Types

This folder contains all models that are required when interacting with the Acuvity Apex API.
They lie at the heart of this SDK.

All files in this folder have been auto-generated by `regolithe-python`.
If you need to make changes to any of the types/models here, you must make them in the source regolithe spec files.
